part of image_capture_field;

class ImageCaptureField extends StatelessWidget {
  ImageCaptureField({
    Key? key,
    required this.controller,
    required this.width,
    required this.height,
    this.imageQuality = 12,
    this.borderRadiusValue = 16,
    this.bottomRightDistance = 12,
  }) : super(key: key);

  ///this [width] is the height of the widget
  final double width;

  ///this [height] is the height of the widget
  final double height;

  ///this [imageQuality] is the default image compressor of image_picker ranges from 0-100
  final int imageQuality;

  ///this [borderRadiusValue] is the widget circular border radius value
  final double borderRadiusValue;

  ///this [bottomRightDistance] is the distance from bottom and right side to the camera icon of the widget
  final double bottomRightDistance;

  // final Rxn<PickedFile> pickedFile;
  final ImageCaptureController controller;
  final _picker = ImagePicker();

  @override
  Widget build(BuildContext context) {
    return Obx(() {
      return InkWell(
        onTap: () async {
          kIsWeb
              ? await controller.updatePickedImage(
                  await _picker.getImage(
                    source: ImageSource.camera,
                    imageQuality: imageQuality,
                  ),
                )
              : showModalBottomSheet(
                  context: context,
                  builder: (ctx) {
                    return Container(
                      color: Colors.black,
                      child: Padding(
                        padding: const EdgeInsets.all(18),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Padding(
                              padding: const EdgeInsets.fromLTRB(5, 0, 5, 25),
                              child: Text(
                                'Open with',
                                textScaleFactor: 1.2,
                                style: TextStyle(
                                    color: Colors.white,
                                    fontWeight: FontWeight.bold),
                              ),
                            ),
                            Row(
                              mainAxisAlignment: MainAxisAlignment.start,
                              children: [
                                SizedBox(width: 20),
                                OpenWithButton(
                                  iconName: 'Camera',
                                  iconData: Icons.camera_alt,
                                  onTap: () async {
                                    await controller.updatePickedImage(
                                      await _picker.getImage(
                                        source: ImageSource.camera,
                                        imageQuality: imageQuality,
                                      ),
                                    );
                                    Navigator.of(context).pop();
                                  },
                                ),
                                SizedBox(
                                  width: 30,
                                ),
                                OpenWithButton(
                                  iconName: 'Gallery',
                                  iconData: Icons.photo,
                                  onTap: () async {
                                    await controller.updatePickedImage(
                                      await _picker.getImage(
                                        source: ImageSource.gallery,
                                        imageQuality: imageQuality,
                                      ),
                                    );
                                    Navigator.of(context).pop();
                                  },
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    );
                  },
                );
        },
        child: Stack(
          children: [
            Material(
              borderRadius:
                  BorderRadius.all(Radius.circular(borderRadiusValue)),
              clipBehavior: Clip.hardEdge,
              elevation: 6,
              child: Container(
                alignment: Alignment.bottomRight,
                width: width,
                height: height,
                decoration: BoxDecoration(
                  color: Colors.grey,
                  image: controller.isBlankUInt8List
                      ? null
                      : DecorationImage(
                          image: MemoryImage(controller.imageUInt8List!),
                          fit: BoxFit.cover,
                        ),
                ),
              ),
            ),
            Positioned(
              bottom: bottomRightDistance,
              right: bottomRightDistance,
              child: CircleAvatar(
                backgroundColor: Colors.teal,
                radius: 20,
                child: Icon(
                  Icons.camera_alt,
                  color: Colors.white,
                ),
              ),
            ),
          ],
        ),
      );
    });
  }
}

class OpenWithButton extends StatelessWidget {
  const OpenWithButton({
    Key? key,
    required this.onTap,
    required this.iconData,
    required this.iconName,
  }) : super(key: key);
  final Function() onTap;
  final IconData iconData;
  final String iconName;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Column(
        children: [
          CircleAvatar(
            backgroundColor: Colors.teal,
            child: Icon(iconData),
          ),
          SizedBox(height: 5),
          Text(
            iconName,
            textScaleFactor: 0.9,
            style: TextStyle(
              color: Colors.white,
            ),
          ),
        ],
      ),
    );
  }
}
